pub struct RogueNetAgent { /* private fields */ }Expand description
Agent that implements the RogueNet entity neural network. Can be loaded from checkpoints produced by enn-trainer.
Implementations
Sourceimpl RogueNetAgent
impl RogueNetAgent
Sourcepub fn load<P: AsRef<Path>>(path: P) -> Result<Self, Error>
pub fn load<P: AsRef<Path>>(path: P) -> Result<Self, Error>
Loads a neural network agent from an enn-trainer checkpoint directory.
Sourcepub fn load_archive<R: Read>(reader: R) -> Result<Self, Error>
pub fn load_archive<R: Read>(reader: R) -> Result<Self, Error>
Loads a neural network agent from an archive of a checkpoint directory.
You can use the rogue-net cli to create a tar archive of a checkpoint directory:
$ cargo install rogue-net
$ rogue-net archive --path path/to/checkpoint/dirSourcepub fn with_feature_adaptor<E: Featurizable>(self) -> Self
pub fn with_feature_adaptor<E: Featurizable>(self) -> Self
Adapts the network to a changed observation space.
If you trained a network with a different observation space, you can adapt it to the new observation space. For this to work, the new set of features of the observation space must be a superset of the old set of features.